@@ -1,10 +1,15 @@
+# Licensed to Elasticsearch B.V under one or more agreements.
+# Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
+# See the LICENSE file in the project root for more information
+
 # flake8: noqa
 from __future__ import absolute_import
 
-VERSION = (7, 7, 1)
+VERSION = (7, 8, 0)
 __version__ = VERSION
-__versionstr__ = "7.7.1"
+__versionstr__ = "7.8.0"
 
+import sys
 import logging
 import warnings
 
@@ -60,3 +65,16 @@ __all__ = [
     "AuthorizationException",
     "ElasticsearchDeprecationWarning",
 ]
+
+try:
+    # Asyncio only supported on Python 3.6+
+    if sys.version_info < (3, 6):
+        raise ImportError
+
+    from ._async.http_aiohttp import AIOHttpConnection
+    from ._async.transport import AsyncTransport
+    from ._async.client import AsyncElasticsearch
+
+    __all__ += ["AIOHttpConnection", "AsyncTransport", "AsyncElasticsearch"]
+except (ImportError, SyntaxError):
+    pass
